@@ -7,6 +7,7 @@ import pytz
 
 from pyhamtools.consts import LookupConventions as const
 
+from pyhamtools.callsign_exceptions import callsign_exceptions
 
 UTC = pytz.UTC
 timestamp_now = datetime.utcnow().replace(tzinfo=UTC)
@@ -81,6 +82,10 @@ class Callinfo(object):
         """truncate call until it corresponds to a Prefix in the database"""
         prefix = callsign
 
+        if re.search('(VK|AX|VI)9[A-Z]{3}', callsign): #special rule for VK9 calls
+            if timestamp > datetime(2006,1,1, tzinfo=UTC):
+                prefix = callsign[0:3]+callsign[4:5]
+
         while len(prefix) > 0:
             try:
                 return self._lookuplib.lookup_prefix(prefix, timestamp)
@@ -91,26 +96,18 @@ class Callinfo(object):
 
     @staticmethod
     def check_if_mm(callsign):
-        if re.search("/MM$", callsign.upper()):
-            return True
-        else:
-            return False
+        check = callsign[-3:].upper()
+        return "/MM" in check
 
     @staticmethod
     def check_if_am(callsign):
-        if re.search("/AM$", callsign.upper()):
-            return True
-        else:
-            return False
+        check = callsign[-3:].upper()
+        return "/AM" in check
 
     @staticmethod
     def check_if_beacon(callsign):
-        if re.search("/B$", callsign.upper()):
-            return True
-        elif re.search("/BCN$", callsign.upper()):
-            return True
-        else:
-            return False
+        check = callsign[-4:].upper()
+        return "/B" in check or "/BCN" in check
 
     def _dismantle_callsign(self, callsign, timestamp=timestamp_now):
         """ try to identify the callsign's identity by analyzing it in the following order:
@@ -131,7 +128,7 @@ class Callinfo(object):
             if re.search('\-\d{1,3}$', entire_callsign):  # cut off any -10 / -02 appendixes
                 callsign = re.sub('\-\d{1,3}$', '', entire_callsign)
 
-            if re.search('/[A-Z0-9]{2,4}/[A-Z0-9]{1,4}$', callsign):
+            if re.search('/[A-Z0-9]{1,4}/[A-Z0-9]{1,4}$', callsign):
                 callsign = re.sub('/[A-Z0-9]{1,4}$', '', callsign)  # cut off 2. appendix DH1TW/HC2/P -> DH1TW/HC2
 
             # multiple character appendix (callsign/xxx)
@@ -173,6 +170,10 @@ class Callinfo(object):
                 elif appendix == "LH":  # Filter all Lighthouses
                     callsign = re.sub('/LH', '', callsign)
                     return self._iterate_prefix(callsign, timestamp)
+                elif re.search('[A-Z]{3}', appendix): #case of US county(?) contest N3HBX/UAL
+                    callsign = re.sub('/[A-Z]{3}$', '', callsign)
+                    return self._iterate_prefix(callsign, timestamp)
+
                 else:
                     # check if the appendix is a valid country prefix
                     return self._iterate_prefix(re.sub('/', '', appendix), timestamp)
@@ -190,8 +191,11 @@ class Callinfo(object):
 
                 elif re.search('\d$', appendix):
                     area_nr = re.search('\d$', appendix).group(0)
-                    callsign = re.sub('/\d$', '', callsign)
-                    callsign = re.sub('[\d]+', area_nr, callsign)
+                    callsign = re.sub('/\d$', '', callsign) #remove /number
+                    if len(re.findall(r'\d+', callsign)) == 1: #call has just on digit e.g. DH1TW
+                        callsign = re.sub('[\d]+', area_nr, callsign)
+                    else: # call has several digits e.g. 7N4AAL
+                        pass # no (two) digit prefix contries known where appendix would change entitiy
                     return self._iterate_prefix(callsign, timestamp)
 
                 else:
@@ -205,18 +209,25 @@ class Callinfo(object):
             elif re.search('^[A-Z0-9]{1,4}/', entire_callsign):
                 pfx = re.search('^[A-Z0-9]{1,4}/', entire_callsign)
                 pfx = re.sub('/', '', pfx.group(0))
-                return self._iterate_prefix(pfx)
+                #make sure that the remaining part is actually a callsign (avoid: OZ/JO81)
+                rest = re.search('/[A-Z0-9]+', entire_callsign)
+                rest = re.sub('/', '', rest.group(0))
+                if re.match('^[\d]{0,1}[A-Z]{1,2}\d([A-Z]{1,4}|\d{3,3}|\d{1,3}[A-Z])[A-Z]{0,5}$', rest):
+                    return self._iterate_prefix(pfx)
+
+        if entire_callsign in callsign_exceptions:
+            return self._iterate_prefix(callsign_exceptions[entire_callsign])
 
         self._logger.debug("Could not decode " + callsign)
-        raise KeyError
+        raise KeyError("Callsign could not be decoded")
 
     def _lookup_callsign(self, callsign, timestamp=timestamp_now):
 
         # Check if operation is invalid
         invalid = False
         try:
-            if self._lookuplib.is_invalid_operation(callsign, timestamp):
-                invalid = True
+            invalid = self._lookuplib.is_invalid_operation(callsign, timestamp)
+            if invalid:
                 raise KeyError
         except KeyError:
             if invalid:
@@ -241,7 +252,7 @@ class Callinfo(object):
                 'longitude': 0.0
             }
 
-        # Check if a dedicated entry exists for the callsign
+        # Check if a dedicated entry/exception exists for the callsign
         try:
             data = self._lookuplib.lookup_callsign(callsign, timestamp).copy()
             if self.check_if_beacon(callsign):
@@ -291,7 +302,7 @@ class Callinfo(object):
             would be missing with Clublog (API or XML) :py:class:`LookupLib`.
 
         """
-        callsign_data = self._lookup_callsign(callsign, timestamp_now)
+        callsign_data = self._lookup_callsign(callsign, timestamp)
 
         try:
             cqz = self._lookuplib.lookup_zone_exception(callsign, timestamp)
@@ -355,7 +366,7 @@ class Callinfo(object):
         Note:
             Unfortunately, in most cases the returned Latitude and Longitude are not very precise.
             Clublog and Country-files.com use the country's capital coordinates in most cases, if no
-            dedicated entry in the database exists.
+            dedicated entry in the database exists. Best results will be retrieved with QRZ.com Lookup.
 
         """
         callsign_data = self.get_all(callsign, timestamp=timestamp)
@@ -463,4 +474,4 @@ class Callinfo(object):
             - OC: Oceania
             - AN: Antarctica
         """
-        return self.get_all(callsign, timestamp)[const.CONTINENT]
\ No newline at end of file
+        return self.get_all(callsign, timestamp)[const.CONTINENT]
