@@ -1,3 +1,4 @@
+from __future__ import unicode_literals
 import os
 import logging
 import logging.config
@@ -16,10 +17,9 @@ from requests.exceptions import ConnectionError, HTTPError, Timeout
 from bs4 import BeautifulSoup
 import pytz
 
-
-import version
-from consts import LookupConventions as const
-from exceptions import APIKeyMissingError
+from . import version
+from .consts import LookupConventions as const
+from .exceptions import APIKeyMissingError
 
 UTC = pytz.UTC
 timestamp_now = datetime.utcnow().replace(tzinfo=UTC)
@@ -29,6 +29,9 @@ if sys.version_info < (2, 7,):
         def emit(self, record):
             pass
 
+if sys.version_info.major == 3:
+    unicode = str
+
 class LookupLib(object):
     """
 
@@ -37,6 +40,7 @@ class LookupLib(object):
     1. Clublog.org (daily updated XML File)
     2. Clublog.org (HTTPS lookup)
     3. Country-files.com (infrequently updated PLIST File)
+    4. QRZ.com (HTTP / XML Lookup)
 
     It's aim is to provide a homogeneous interface to different databases.
 
@@ -47,18 +51,19 @@ class LookupLib(object):
     The documentation of the various methods provide more detail.
 
     By default, LookupLib requires an Internet connection to download the libraries or perform the
-    lookup against the Clublog API.
+    lookup against the Clublog API or QRZ.com.
 
-    The entire lookup data can also be copied into Redis, which an extremely fast in-memory Key/Value store.
-    A LookupLib object can be instanciated to perform then all lookups in Redis, instead processing and loading
-    the data from Internet / File. This saves some time and allows several instances of :py:class:`LookupLib`
-    to query the same data concurrently.
+    The entire lookup data (where database files are downloaded) can also be copied into Redis, which an extremely
+    fast in-memory Key/Value store. A LookupLib object can be instanciated to perform then all lookups in Redis,
+    instead processing and loading the data from Internet / File. This saves some time and allows several instances
+    of :py:class:`LookupLib` to query the same data concurrently.
 
     Args:
-        lookuptype (str) : "clublogxml" or "clublogapi" or "countryfile" or "redis"
+        lookuptype (str) : "clublogxml" or "clublogapi" or "countryfile" or "redis" or "qrz"
         apikey (str): Clublog API Key
         username (str): QRZ.com username
         pwd (str): QRZ.com password
+        apiv (str, optional): QRZ.com API Version
         filename (str, optional): Filename for Clublog XML or Country-files.com cty.plist file. When a local file is
         used, no Internet connection not API Key is necessary.
         logger (logging.getLogger(__name__), optional): Python logger
@@ -67,7 +72,7 @@ class LookupLib(object):
 
 
     """
-    def __init__(self, lookuptype = "countryfile", apikey=None, filename=None, logger=None, username=None, pwd=None, redis_instance=None, redis_prefix=None):
+    def __init__(self, lookuptype = "countryfile", apikey=None, apiv="1.3.3", filename=None, logger=None, username=None, pwd=None, redis_instance=None, redis_prefix=None):
 
         self._logger = None
         if logger:
@@ -80,6 +85,7 @@ class LookupLib(object):
                 self._logger.addHandler(logging.NullHandler())
 
         self._apikey = apikey
+        self._apiv = apiv
         self._download = True
         self._lib_filename = filename
         self._redis = redis_instance
@@ -112,21 +118,24 @@ class LookupLib(object):
             self._apikey = self._get_qrz_session_key(self._username, self._pwd)
         else:
             raise AttributeError("Lookup type missing")
-            
+
     def _get_qrz_session_key(self, username, pwd):
-        
+
         qrz_api_version = "1.3.3"
         url = "https://xmldata.qrz.com/xml/" + qrz_api_version + "/"
-        agent = "PyHT"+version.__version__
-        
+        agent = "PyHamTools"+version.__version__
+
         params = {"username" : username,
-            "password" : pwd, 
+            "password" : pwd,
             "agent" : agent
         }
 
-        encodeurl = url + "?" + urllib.urlencode(params)
-        response = requests.get(encodeurl, timeout=5)
-        doc = BeautifulSoup(response.text)
+        if sys.version_info.major == 3:
+            encodeurl = url + "?" + urllib.parse.urlencode(params)
+        else:
+            encodeurl = url + "?" + urllib.urlencode(params)
+        response = requests.get(encodeurl, timeout=10)
+        doc = BeautifulSoup(response.text, "html.parser")
         session_key = None
         if doc.session.key:
             session_key = doc.session.key.text
@@ -137,7 +146,7 @@ class LookupLib(object):
                 raise ValueError("Could not retrieve Session Key from QRZ.com")
 
         return session_key
-        
+
 
     def copy_data_in_redis(self, redis_prefix, redis_instance):
         """
@@ -162,7 +171,7 @@ class LookupLib(object):
            True
 
            Now let's create an instance of LookupLib, using Redis to query the data
-           
+
            >>> from pyhamtools import LookupLib
            >>> import redis
            >>> r = redis.Redis()
@@ -175,7 +184,7 @@ class LookupLib(object):
              u'cqz': 32,
              u'ituz': 56,
              u'latitude': -12.48,
-             u'longitude': -177.08
+             u'longitude': 177.08
            }
 
 
@@ -253,7 +262,7 @@ class LookupLib(object):
            {
             'deleted': False,
             'country': u'TURKMENISTAN',
-            'longitude': -58.4,
+            'longitude': 58.4,
             'cqz': 17,
             'prefix': u'EZ',
             'latitude': 38.0,
@@ -265,8 +274,8 @@ class LookupLib(object):
             This method is available for the following lookup type
 
             - clublogxml
-            - qrz
             - redis
+            - qrz.com
 
         """
         if self._lookuptype == "clublogxml":
@@ -288,7 +297,7 @@ class LookupLib(object):
         elif self._lookuptype == "qrz":
             result = self._lookup_qrz_dxcc(entity, self._apikey)
             return result
-            
+
         # no matching case
         raise KeyError
 
@@ -336,7 +345,7 @@ class LookupLib(object):
            >>> print my_lookuplib.lookup_callsign("VK9XO", timestamp)
            {
             'country': u'CHRISTMAS ISLAND',
-            'longitude': -105.7,
+            'longitude': 105.7,
             'cqz': 29,
             'adif': 35,
             'latitude': -10.5,
@@ -349,8 +358,10 @@ class LookupLib(object):
             - clublogxml
             - clublogapi
             - countryfile
+            - qrz.com
             - redis
 
+
         """
         callsign = callsign.strip().upper()
 
@@ -372,8 +383,8 @@ class LookupLib(object):
 
         # no matching case
         elif self._lookuptype == "qrz":
-            pass
-        
+            return self._lookup_qrz_callsign(callsign, self._apikey, self._apiv)
+
         raise KeyError("unknown Callsign")
 
     def _get_dicts_from_redis(self, name, index_name, redis_prefix, item):
@@ -389,10 +400,10 @@ class LookupLib(object):
             raise KeyError ("redis_prefix is missing")
 
         if r.scard(redis_prefix + index_name + str(item)) > 0:
-            data_index_dict[item] = r.smembers(redis_prefix + index_name + str(item))
+            data_index_dict[str(item)] = r.smembers(redis_prefix + index_name + str(item))
 
             for i in data_index_dict[item]:
-                json_data = r.get(redis_prefix + name + i)
+                json_data = r.get(redis_prefix + name + str(int(i)))
                 data_dict[i] = self._deserialize_data(json_data)
 
             return (data_dict, data_index_dict)
@@ -496,7 +507,7 @@ class LookupLib(object):
            {
             'adif': 230,
             'country': u'Fed. Rep. of Germany',
-            'longitude': -10.0,
+            'longitude': 10.0,
             'cqz': 14,
             'ituz': 28,
             'latitude': 51.0,
@@ -675,77 +686,86 @@ class LookupLib(object):
             "call" : callsign
         }
 
-        encodeurl = url + "?" + urllib.urlencode(params)
+        if sys.version_info.major == 3:
+            encodeurl = url + "?" + urllib.parse.urlencode(params)
+        else:
+            encodeurl = url + "?" + urllib.urlencode(params)
         response = requests.get(encodeurl, timeout=5)
 
         if not self._check_html_response(response):
             raise LookupError
 
-        jsonLookup = json.loads(response.text)
+        jsonLookup = response.json()
         lookup = {}
 
         for item in jsonLookup:
             if item == "Name": lookup[const.COUNTRY] = jsonLookup["Name"]
             elif item == "DXCC": lookup[const.ADIF] = int(jsonLookup["DXCC"])
-            elif item == "Lon": lookup[const.LONGITUDE] = float(jsonLookup["Lon"])
+            elif item == "Lon": lookup[const.LONGITUDE] = float(jsonLookup["Lon"])*(-1)
             elif item == "Lat": lookup[const.LATITUDE] = float(jsonLookup["Lat"])
             elif item == "CQZ": lookup[const.CQZ] = int(jsonLookup["CQZ"])
             elif item == "Continent": lookup[const.CONTINENT] = jsonLookup["Continent"]
-            
+
         if lookup[const.ADIF] == 0:
             raise KeyError
         else:
             return lookup
-            
-    def _request_callsign_info_from_qrz(self, callsign, apikey):
-        qrz_api_version = "1.3.3"
+
+    def _request_callsign_info_from_qrz(self, callsign, apikey, apiv="1.3.3"):
+        qrz_api_version = apiv
         url = "https://xmldata.qrz.com/xml/" + qrz_api_version + "/"
-        
+
         params = {
             "s": apikey,
-            "callsign" : callsign, 
+            "callsign" : callsign,
         }
-        
-        encodeurl = url + "?" + urllib.urlencode(params)
+
+        if sys.version_info.major == 3:
+            encodeurl = url + "?" + urllib.parse.urlencode(params)
+        else:
+            encodeurl = url + "?" + urllib.urlencode(params)
         response = requests.get(encodeurl, timeout=5)
         return response
-        
-    def _request_dxcc_info_from_qrz(self, dxcc_or_callsign, apikey):
-        qrz_api_version = "1.3.3"
+
+    def _request_dxcc_info_from_qrz(self, dxcc_or_callsign, apikey, apiv="1.3.3"):
+        qrz_api_version = apiv
         url = "https://xmldata.qrz.com/xml/" + qrz_api_version + "/"
-        
+
         params = {
             "s": apikey,
-            "dxcc" : str(dxcc_or_callsign), 
+            "dxcc" : str(dxcc_or_callsign),
         }
-        
-        encodeurl = url + "?" + urllib.urlencode(params)
+
+        if sys.version_info.major == 3:
+            encodeurl = url + "?" + urllib.parse.urlencode(params)
+        else:
+            encodeurl = url + "?" + urllib.urlencode(params)
         response = requests.get(encodeurl, timeout=5)
         return response
-        
-    def _lookup_qrz_dxcc(self, dxcc_or_callsign, apikey):
+
+    def _lookup_qrz_dxcc(self, dxcc_or_callsign, apikey, apiv="1.3.3"):
         """ Performs the dxcc lookup against the QRZ.com XML API:
         """
-        
-        response = self._request_dxcc_info_from_qrz(dxcc_or_callsign, apikey)
-        
-        root = BeautifulSoup(response.text)
+
+        response = self._request_dxcc_info_from_qrz(dxcc_or_callsign, apikey, apiv=apiv)
+
+        root = BeautifulSoup(response.text, "html.parser")
         lookup = {}
 
         if root.error: #try to get a new session key and try to request again
-        
+
             if re.search('No DXCC Information for', root.error.text, re.I):  #No data available for callsign
                 raise KeyError(root.error.text)
             elif re.search('Session Timeout', root.error.text, re.I): # Get new session key
                 self._apikey = apikey = self._get_qrz_session_key(self._username, self._pwd)
                 response = self._request_dxcc_info_from_qrz(dxcc_or_callsign, apikey)
-                root = BeautifulSoup(response.text)
+                root = BeautifulSoup(response.text, "html.parser")
             else:
                 raise AttributeError("Session Key Missing") #most likely session key missing or invalid
-        
+
         if root.dxcc is None:
             raise ValueError
-        
+
         if root.dxcc.dxcc:
             lookup[const.ADIF] = int(root.dxcc.dxcc.text)
         if root.dxcc.cc:
@@ -766,156 +786,170 @@ class LookupLib(object):
             lookup[const.LATITUDE] = float(root.dxcc.lat.text)
         if root.dxcc.lon:
             lookup[const.LONGITUDE] = float(root.dxcc.lon.text)
-        
+
         return lookup
-        
-        
-    def _lookup_qrz_callsign(self, callsign=None, apikey=None):
+
+
+    def _lookup_qrz_callsign(self, callsign=None, apikey=None, apiv="1.3.3"):
         """ Performs the callsign lookup against the QRZ.com XML API:
         """
-        
+
         if apikey is None:
             raise AttributeError("Session Key Missing")
-    
-        callsign = callsign.upper() 
-        
-        response = self._request_callsign_info_from_qrz(callsign, apikey)
-        
-        root = BeautifulSoup(response.text)
+
+        callsign = callsign.upper()
+
+        response = self._request_callsign_info_from_qrz(callsign, apikey, apiv)
+
+        root = BeautifulSoup(response.text, "html.parser")
         lookup = {}
 
-        if root.error: #try to get a new session key and try to request again
-        
+        if root.error:
+
             if re.search('Not found', root.error.text, re.I):  #No data available for callsign
                 raise KeyError(root.error.text)
-            elif re.search('Session Timeout', root.error.text, re.I): # Get new session key
-                self._apikey = apikey = self._get_qrz_session_key(self._username, self._pwd)
-                response = self._request_callsign_info_from_qrz(callsign, apikey)
-                root = BeautifulSoup(response.text)
+
+            #try to get a new session key and try to request again
+            elif re.search('Session Timeout', root.error.text, re.I) or re.search('Invalid session key', root.error.text, re.I):
+                apikey = self._get_qrz_session_key(self._username, self._pwd)
+                response = self._request_callsign_info_from_qrz(callsign, apikey, apiv)
+                root = BeautifulSoup(response.text, "html.parser")
+
+                #if this fails again, raise error
+                if root.error:
+
+                    if re.search('Not found', root.error.text, re.I):  #No data available for callsign
+                        raise KeyError(root.error.text)
+                    else:
+                        raise AttributeError(root.error.text) #most likely session key invalid
+                else:
+                    #update API Key ob Lookup object
+                    self._apikey = apikey
+
             else:
-                raise AttributeError(root.error.text) #most likely session key missing or invalid
+                raise AttributeError(root.error.text) #most likely session key missing
 
         if root.callsign is None:
             raise ValueError
 
         if root.callsign.call:
-            lookup['call'] = root.callsign.call.text
+            lookup[const.CALLSIGN] = root.callsign.call.text
         if root.callsign.xref:
-            lookup['xref'] = root.callsign.xref.text
-        if root.callsign.aliases:  
-            lookup['aliases'] = root.callsign.aliases.text.split(',')
+            lookup[const.XREF] = root.callsign.xref.text
+        if root.callsign.aliases:
+            lookup[const.ALIASES] = root.callsign.aliases.text.split(',')
         if root.callsign.dxcc:
             lookup[const.ADIF] = int(root.callsign.dxcc.text)
         if root.callsign.fname:
-            lookup['fname'] = root.callsign.fname.text
+            lookup[const.FNAME] = root.callsign.fname.text
         if root.callsign.find("name"):
-            lookup['name'] = root.callsign.find('name').get_text()
-        if root.callsign.addr1: 
-            lookup['addr1'] = root.callsign.addr1.text
-        if root.callsign.addr2: 
-            lookup['addr2'] = root.callsign.addr2.text
+            lookup[const.NAME] = root.callsign.find('name').get_text()
+        if root.callsign.addr1:
+            lookup[const.ADDR1] = root.callsign.addr1.text
+        if root.callsign.addr2:
+            lookup[const.ADDR2] = root.callsign.addr2.text
         if root.callsign.state:
-            lookup['state'] = root.callsign.state.text
+            lookup[const.STATE] = root.callsign.state.text
         if root.callsign.zip:
-            lookup['zip'] = root.callsign.zip.text
+            lookup[const.ZIPCODE] = root.callsign.zip.text
         if root.callsign.country:
             lookup[const.COUNTRY] = root.callsign.country.text
-        if root.callsign.ccode: 
-            lookup['ccode'] = int(root.callsign.ccode.text)
-        if root.callsign.lat: 
+        if root.callsign.ccode:
+            lookup[const.CCODE] = int(root.callsign.ccode.text)
+        if root.callsign.lat:
             lookup[const.LATITUDE] = float(root.callsign.lat.text)
-        if root.callsign.lon: 
+        if root.callsign.lon:
             lookup[const.LONGITUDE] = float(root.callsign.lon.text)
-        if root.callsign.grid: 
+        if root.callsign.grid:
             lookup[const.LOCATOR] = root.callsign.grid.text
-        if root.callsign.county: 
-            lookup['county'] = root.callsign.county.text
-        if root.callsign.fips: 
-            lookup['fips'] = int(root.callsign.fips.text) # check type
-        if root.callsign.land: 
-            lookup['land'] = root.callsign.land.text
+        if root.callsign.county:
+            lookup[const.COUNTY] = root.callsign.county.text
+        if root.callsign.fips:
+            lookup[const.FIPS] = int(root.callsign.fips.text) # check type
+        if root.callsign.land:
+            lookup[const.LAND] = root.callsign.land.text
         if root.callsign.efdate:
-            try: 
-                lookup['efdate'] = datetime.strptime(root.callsign.efdate.text, '%Y-%m-%d %H:%M:%S')
-            except ValueError:
-                self._logger.warning("[QRZ.com] efdate: Invalid DateTime; " + callsign)
-        if root.callsign.expdate: 
             try:
-                lookup['expdate'] = datetime.strptime(root.callsign.expdate.text, '%Y-%m-%d %H:%M:%S')
+                lookup[const.EFDATE] = datetime.strptime(root.callsign.efdate.text, '%Y-%m-%d').replace(tzinfo=UTC)
             except ValueError:
-                self._logger.warning("[QRZ.com] expdate: Invalid DateTime; " + callsign)
-        if root.callsign.p_call: 
-            lookup['p_call'] = root.callsign.p_call.text
+                self._logger.debug("[QRZ.com] efdate: Invalid DateTime; " + callsign + " " + root.callsign.efdate.text)
+        if root.callsign.expdate:
+            try:
+                lookup[const.EXPDATE] = datetime.strptime(root.callsign.expdate.text, '%Y-%m-%d').replace(tzinfo=UTC)
+            except ValueError:
+                self._logger.debug("[QRZ.com] expdate: Invalid DateTime; " + callsign + " " + root.callsign.expdate.text)
+        if root.callsign.p_call:
+            lookup[const.P_CALL] = root.callsign.p_call.text
         if root.callsign.find('class'):
-             lookup['class'] = root.callsign.find('class').get_text()
-        if root.callsign.codes: 
-            lookup['codes'] = root.callsign.codes.text
-        if root.callsign.qslmgr: 
-            lookup['qslmgr'] = root.callsign.qslmgr.text
-        if root.callsign.email: 
-            lookup['email'] = root.callsign.email.text
-        if root.callsign.url: 
-            lookup['url'] = root.callsign.url.text
+             lookup[const.LICENSE_CLASS] = root.callsign.find('class').get_text()
+        if root.callsign.codes:
+            lookup[const.CODES] = root.callsign.codes.text
+        if root.callsign.qslmgr:
+            lookup[const.QSLMGR] = root.callsign.qslmgr.text
+        if root.callsign.email:
+            lookup[const.EMAIL] = root.callsign.email.text
+        if root.callsign.url:
+            lookup[const.URL] = root.callsign.url.text
         if root.callsign.u_views:
-            lookup['u_views'] = int(root.callsign.u_views.text)
-        if root.callsign.bio: 
-            lookup['bio'] = root.callsign.bio.text
+            lookup[const.U_VIEWS] = int(root.callsign.u_views.text)
+        if root.callsign.bio:
+            lookup[const.BIO] = root.callsign.bio.text
         if root.callsign.biodate:
             try:
-                lookup['biodate'] = datetime.strptime(root.callsign.biodate.text, '%Y-%m-%d %H:%M:%S')
+                lookup[const.BIODATE] = datetime.strptime(root.callsign.biodate.text, '%Y-%m-%d %H:%M:%S').replace(tzinfo=UTC)
             except ValueError:
                 self._logger.warning("[QRZ.com] biodate: Invalid DateTime; " + callsign)
-        if root.callsign.image: 
-            lookup['image'] = root.callsign.image.text
+        if root.callsign.image:
+            lookup[const.IMAGE] = root.callsign.image.text
         if root.callsign.imageinfo:
-            lookup['imageinfo'] = root.callsign.imageinfo.text
-        if root.callsign.serial: 
-            lookup['serial'] = long(root.callsign.serial.text)
+            lookup[const.IMAGE_INFO] = root.callsign.imageinfo.text
+        if root.callsign.serial:
+            lookup[const.SERIAL] = long(root.callsign.serial.text)
         if root.callsign.moddate:
-            try: 
-                lookup['moddate'] = datetime.strptime(root.callsign.moddate.text, '%Y-%m-%d %H:%M:%S')
+            try:
+                lookup[const.MODDATE] = datetime.strptime(root.callsign.moddate.text, '%Y-%m-%d %H:%M:%S').replace(tzinfo=UTC)
             except ValueError:
-                self._logger.warning("[QRZ.com] efdate: Invalid DateTime; " + callsign)
-        if root.callsign.MSA: 
-            lookup['MSA'] = int(root.callsign.MSA.text)
+                self._logger.warning("[QRZ.com] moddate: Invalid DateTime; " + callsign)
+        if root.callsign.MSA:
+            lookup[const.MSA] = int(root.callsign.MSA.text)
         if root.callsign.AreaCode:
-            lookup['AreaCode'] = int(root.callsign.AreaCode.text)
-        if root.callsign.TimeZone: 
-            lookup['TimeZone'] = int(root.callsign.TimeZone.text)
-        if root.callsign.GMTOffset: 
-            lookup['GMTOffset'] = float(root.callsign.GMTOffset.text)
+            lookup[const.AREACODE] = int(root.callsign.AreaCode.text)
+        if root.callsign.TimeZone:
+            lookup[const.TIMEZONE] = int(root.callsign.TimeZone.text)
+        if root.callsign.GMTOffset:
+            lookup[const.GMTOFFSET] = float(root.callsign.GMTOffset.text)
         if root.callsign.DST:
             if root.callsign.DST.text == "Y":
-                lookup['DST'] = True
+                lookup[const.DST] = True
             else:
-                lookup['DST'] = False
-        if root.callsign.eqsl: 
+                lookup[const.DST] = False
+        if root.callsign.eqsl:
             if root.callsign.eqsl.text == "1":
-                lookup['eqsl'] = True
+                lookup[const.EQSL] = True
             else:
-                lookup['eqsl'] = False
+                lookup[const.EQSL] = False
         if root.callsign.mqsl:
             if root.callsign.mqsl.text == "1":
-                lookup['mqsl'] = True
+                lookup[const.MQSL] = True
             else:
-                lookup['mqsl'] = False
+                lookup[const.MQSL] = False
         if root.callsign.cqzone:
             lookup[const.CQZ] = int(root.callsign.cqzone.text)
         if root.callsign.ituzone:
             lookup[const.ITUZ] = int(root.callsign.ituzone.text)
-        if root.callsign.born: 
-            lookup['born'] = int(root.callsign.born.text)
-        if root.callsign.user: 
-            lookup['user'] = root.callsign.user.text
+        if root.callsign.born:
+            lookup[const.BORN] = int(root.callsign.born.text)
+        if root.callsign.user:
+            lookup[const.USER_MGR] = root.callsign.user.text
         if root.callsign.lotw:
             if root.callsign.lotw.text == "1":
-                lookup['lotw'] = True
+                lookup[const.LOTW] = True
             else:
-                lookup['lotw'] = False
+                lookup[const.LOTW] = False
         if root.callsign.iota:
-            lookup['iota'] = root.callsign.iota.text
-        if root.callsign.geoloc: 
-            lookup['geoloc'] = root.callsign.geoloc.text
+            lookup[const.IOTA] = root.callsign.iota.text
+        if root.callsign.geoloc:
+            lookup[const.GEOLOC] = root.callsign.geoloc.text
 
         # if sys.version_info >= (2,):
         #     for item in lookup:
@@ -955,8 +989,8 @@ class LookupLib(object):
         return True
 
     def _load_countryfile(self,
-                         url="http://www.country-files.com/cty/cty.plist", 
-                         country_mapping_filename="countryfilemapping.json", 
+                         url="https://www.country-files.com/cty/cty.plist",
+                         country_mapping_filename="countryfilemapping.json",
                          cty_file=None):
         """ Load and process the ClublogXML file either as a download or from file
         """
@@ -966,6 +1000,8 @@ class LookupLib(object):
 
         # from cwd
         if os.path.exists(cwdFile):
+            # country mapping files contains the ADIF identifiers of a particular
+            # country since the country-files do not provide this information (only DXCC id)
             country_mapping_filename = cwdFile
         # from package
         elif os.path.exists(pkgFile):
@@ -1025,7 +1061,7 @@ class LookupLib(object):
             filename = "cty_" + self._generate_random_word(5)
 
         download_file_path = os.path.join(tempfile.gettempdir(), filename)
-        with open(download_file_path, "w") as download_file:
+        with open(download_file_path, "wb") as download_file:
             download_file.write(response.content)
         self._logger.debug(str(download_file_path) + " successfully downloaded")
 
@@ -1035,7 +1071,7 @@ class LookupLib(object):
             download_file = gzip.open(download_file_path, "r")
             try:
                 cty_file_path = os.path.join(os.path.splitext(download_file_path)[0])
-                with open(cty_file_path, "w") as cty_file:
+                with open(cty_file_path, "wb") as cty_file:
                     cty_file.write(download_file.read())
                 self._logger.debug(str(cty_file_path) + " successfully extracted")
             finally:
@@ -1044,7 +1080,7 @@ class LookupLib(object):
             cty_file_path = download_file_path
 
         return cty_file_path
-    
+
     def _extract_clublog_header(self, cty_xml_filename):
         """
         Extract the header of the Clublog XML File
@@ -1052,22 +1088,22 @@ class LookupLib(object):
 
         cty_header = {}
 
-        try: 
+        try:
             with open(cty_xml_filename, "r") as cty:
                 raw_header = cty.readline()
 
             cty_date = re.search("date='.+'", raw_header)
-            if cty_date: 
+            if cty_date:
                 cty_date = cty_date.group(0).replace("date=", "").replace("'", "")
                 cty_date = datetime.strptime(cty_date[:19], '%Y-%m-%dT%H:%M:%S')
                 cty_date.replace(tzinfo=UTC)
                 cty_header["Date"] = cty_date
-            
+
             cty_ns = re.search("xmlns='.+[']", raw_header)
-            if cty_ns: 
+            if cty_ns:
                 cty_ns = cty_ns.group(0).replace("xmlns=", "").replace("'", "")
                 cty_header['NameSpace'] = cty_ns
-        
+
             if len(cty_header) == 2:
                 self._logger.debug("Header successfully retrieved from CTY File")
             elif len(cty_header) < 2:
@@ -1076,24 +1112,24 @@ class LookupLib(object):
                 for key in cty_header:
                     self._logger.warning(str(key)+": "+str(cty_header[key]))
             return cty_header
-        
-        except Exception as e: 
+
+        except Exception as e:
             self._logger.error("Clublog CTY File could not be opened / modified")
             self._logger.error("Error Message: " + str(e))
             return
 
 
     def _remove_clublog_xml_header(self, cty_xml_filename):
-        """ 
+        """
             remove the header of the Clublog XML File to make it
             properly parseable for the python ElementTree XML parser
-        """        
+        """
         import tempfile
 
         try:
             with open(cty_xml_filename, "r") as f:
                 content = f.readlines()
-            
+
             cty_dir = tempfile.gettempdir()
             cty_name = os.path.split(cty_xml_filename)[1]
             cty_xml_filename_no_header = os.path.join(cty_dir, "NoHeader_"+cty_name)
@@ -1133,44 +1169,49 @@ class LookupLib(object):
 
         #retrieve ADIF Country Entities
         cty_entities = cty_tree.find("entities")
+        self._logger.debug("total entities: " + str(len(cty_entities)))
         if len(cty_entities) > 1:
             for cty_entity in cty_entities:
-                entity = {}
-                for item in cty_entity:
-                    if item.tag == "name":
-                        entity[const.COUNTRY] = unicode(item.text)
-                    elif item.tag == "prefix":
-                        entity[const.PREFIX] = unicode(item.text)
-                    elif item.tag == "deleted":
-                        if item.text == "TRUE":
-                            entity[const.DELETED] = True
-                        else:
-                            entity[const.DELETED] = False
-                    elif item.tag == "cqz":
-                        entity[const.CQZ] = int(item.text)
-                    elif item.tag == "cont":
-                        entity[const.CONTINENT] = unicode(item.text)
-                    elif item.tag == "long":
-                        entity[const.LONGITUDE] = float(item.text)*(-1)
-                    elif item.tag == "lat":
-                        entity[const.LATITUDE] = float(item.text)
-                    elif item.tag == "start":
-                        dt = datetime.strptime(item.text[:19], '%Y-%m-%dT%H:%M:%S')
-                        entity[const.START] = dt.replace(tzinfo=UTC)
-                    elif item.tag == "end":
-                        dt = datetime.strptime(item.text[:19], '%Y-%m-%dT%H:%M:%S')
-                        entity[const.END] = dt.replace(tzinfo=UTC)
-                    elif item.tag == "whitelist":
-                        if item.text == "TRUE":
-                            entity[const.WHITELIST] = True
-                        else:
-                            entity[const.WHITELIST] = False
-                    elif item.tag == "whitelist_start":
-                        dt = datetime.strptime(item.text[:19], '%Y-%m-%dT%H:%M:%S')
-                        entity[const.WHITELIST_START] = dt.replace(tzinfo=UTC)
-                    elif item.tag == "whitelist_end":
-                        dt = datetime.strptime(item.text[:19], '%Y-%m-%dT%H:%M:%S')
-                        entity[const.WHITELIST_END] = dt.replace(tzinfo=UTC)
+                try:
+                    entity = {}
+                    for item in cty_entity:
+                        if item.tag == "name":
+                            entity[const.COUNTRY] = unicode(item.text)
+                            self._logger.debug(unicode(item.text))
+                        elif item.tag == "prefix":
+                            entity[const.PREFIX] = unicode(item.text)
+                        elif item.tag == "deleted":
+                            if item.text == "TRUE":
+                                entity[const.DELETED] = True
+                            else:
+                                entity[const.DELETED] = False
+                        elif item.tag == "cqz":
+                            entity[const.CQZ] = int(item.text)
+                        elif item.tag == "cont":
+                            entity[const.CONTINENT] = unicode(item.text)
+                        elif item.tag == "long":
+                            entity[const.LONGITUDE] = float(item.text)
+                        elif item.tag == "lat":
+                            entity[const.LATITUDE] = float(item.text)
+                        elif item.tag == "start":
+                            dt = datetime.strptime(item.text[:19], '%Y-%m-%dT%H:%M:%S')
+                            entity[const.START] = dt.replace(tzinfo=UTC)
+                        elif item.tag == "end":
+                            dt = datetime.strptime(item.text[:19], '%Y-%m-%dT%H:%M:%S')
+                            entity[const.END] = dt.replace(tzinfo=UTC)
+                        elif item.tag == "whitelist":
+                            if item.text == "TRUE":
+                                entity[const.WHITELIST] = True
+                            else:
+                                entity[const.WHITELIST] = False
+                        elif item.tag == "whitelist_start":
+                            dt = datetime.strptime(item.text[:19], '%Y-%m-%dT%H:%M:%S')
+                            entity[const.WHITELIST_START] = dt.replace(tzinfo=UTC)
+                        elif item.tag == "whitelist_end":
+                            dt = datetime.strptime(item.text[:19], '%Y-%m-%dT%H:%M:%S')
+                            entity[const.WHITELIST_END] = dt.replace(tzinfo=UTC)
+                except AttributeError:
+                    self._logger.error("Error while processing: ")
                 entities[int(cty_entity[0].text)] = entity
             self._logger.debug(str(len(entities))+" Entities added")
         else:
@@ -1197,7 +1238,7 @@ class LookupLib(object):
                     elif item.tag == "cont":
                         call_exception[const.CONTINENT] = unicode(item.text)
                     elif item.tag == "long":
-                        call_exception[const.LONGITUDE] = float(item.text)*(-1)
+                        call_exception[const.LONGITUDE] = float(item.text)
                     elif item.tag == "lat":
                         call_exception[const.LATITUDE] = float(item.text)
                     elif item.tag == "start":
@@ -1238,7 +1279,7 @@ class LookupLib(object):
                     elif item.tag == "cont":
                         prefix[const.CONTINENT] = unicode(item.text)
                     elif item.tag == "long":
-                        prefix[const.LONGITUDE] = float(item.text)*(-1)
+                        prefix[const.LONGITUDE] = float(item.text)
                     elif item.tag == "lat":
                         prefix[const.LATITUDE] = float(item.text)
                     elif item.tag == "start":
@@ -1331,7 +1372,7 @@ class LookupLib(object):
         """
 
         import plistlib
-        
+
         cty_list = None
         entities = {}
         exceptions = {}
@@ -1346,7 +1387,7 @@ class LookupLib(object):
         mapping = None
 
         with open(country_mapping_filename, "r") as f:
-            mapping = json.loads(f.read())
+            mapping = json.loads(f.read(),encoding='UTF-8')
 
         cty_list = plistlib.readPlist(cty_file)
 
@@ -1360,7 +1401,7 @@ class LookupLib(object):
             entry[const.ITUZ] = int(cty_list[item]["ITUZone"])
             entry[const.CONTINENT] = unicode(cty_list[item]["Continent"])
             entry[const.LATITUDE] = float(cty_list[item]["Latitude"])
-            entry[const.LONGITUDE] = float(cty_list[item]["Longitude"])
+            entry[const.LONGITUDE] = float(cty_list[item]["Longitude"])*(-1)
 
             if cty_list[item]["ExactCallsign"]:
                 if call in exceptions_index.keys():
@@ -1395,7 +1436,7 @@ class LookupLib(object):
         """
             Generates a random word
         """
-        return ''.join(random.choice(string.lowercase) for i in xrange(length))
+        return ''.join(random.choice(string.ascii_lowercase) for _ in range(length))
 
     def _check_html_response(self, response):
         """
@@ -1410,7 +1451,7 @@ class LookupLib(object):
         else:
             err_str = "HTTP Status Code: " + str(response.status_code) + " HTTP Response: " + str(response.text)
             self._logger.error(err_str)
-            if response.text.strip() == error1 or response.text.strip() == error2:
+            if response.status_code == 403:
                 raise APIKeyMissingError
             else:
                 raise LookupError(err_str)
@@ -1434,7 +1475,8 @@ class LookupLib(object):
         Deserialize a JSON into a dictionary
         """
 
-        my_dict = json.loads(json_data)
+        my_dict = json.loads(json_data.decode('utf8').replace("'", '"'),
+            encoding='UTF-8')
 
         for item in my_dict:
             if item == const.ADIF:
@@ -1471,4 +1513,3 @@ class LookupLib(object):
             return False
         else:
             raise KeyError
-
