@@ -1,8 +1,12 @@
+from __future__ import unicode_literals
 import pytest
+import sys
 
 from pyhamtools.lookuplib import LookupLib
 from pyhamtools.exceptions import APIKeyMissingError
 
+if sys.version_info.major == 3:
+    unicode = str
 
 @pytest.fixture(scope="function", params=[5, -5,  "", "foo bar", 11.5, {}, [], None, ("foo", "bar")])
 def fixAnyValue(request):
@@ -20,7 +24,7 @@ class TestlookupLib:
 
 
 class TestlookupLibHelper:
-    
+
     # def test_checkApiKeyValidity(self, fixClublogApi, fixApiKey):
     #
     #     with pytest.raises(AttributeError):
@@ -30,13 +34,12 @@ class TestlookupLibHelper:
     #         fixClublogApi._checkApiKeyValidity(apikey="")
     #
     #     assert fixClublogApi._checkApiKeyValidity(apikey=fixApiKey) is True
-        
-    
+
+
     def test_generateRandomWord(self, fixClublogApi, fixNonUnsignedInteger):
-        
+
         with pytest.raises(TypeError):
             fixClublogApi._generate_random_word()
 
-        assert type(fixClublogApi._generate_random_word(5)) is str
+        assert type(fixClublogApi._generate_random_word(5)) is unicode
         assert len(fixClublogApi._generate_random_word(5)) is 5
-        
\ No newline at end of file
