@@ -5,7 +5,7 @@ from datetime import datetime
 import pytz
 import redis
 
-from pyhamtools import LookupLib
+from pyhamtools import LookupLib, Callinfo
 
 
 UTC = pytz.UTC
@@ -13,6 +13,16 @@ UTC = pytz.UTC
 r = redis.Redis()
 
 
+response_Exception_VP8STI_with_start_and_stop_date = {
+           'adif': 240,
+           'country': u'SOUTH SANDWICH ISLANDS',
+           'continent': u'SA',
+           'latitude': -59.48,
+           'longitude': -27.29,
+           'cqz': 13,
+        }
+
+
 class TestStoreDataInRedis:
 
     def test_copy_data_in_redis(self, fixClublogXML, fix_redis):
@@ -39,4 +49,9 @@ class TestStoreDataInRedis:
         lib = LookupLib(lookuptype="redis", redis_prefix="CF", redis_instance=r)
         fixCountryFile.copy_data_in_redis("CF", r)
         assert lib.lookup_callsign("3D2RI") == fixCountryFile.lookup_callsign("3D2RI")
-        assert lib.lookup_prefix("DH") == fixCountryFile.lookup_prefix("DH")
\ No newline at end of file
+        assert lib.lookup_prefix("DH") == fixCountryFile.lookup_prefix("DH")
+
+    def test_redis_lookup(self, fixClublogXML, fix_redis):
+        timestamp = datetime(year=2016, month=1, day=20, tzinfo=UTC)
+        ci = Callinfo(fix_redis)
+        assert ci.get_all("VP8STI", timestamp) == response_Exception_VP8STI_with_start_and_stop_date
